==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/RecentFileListHelper.java <==
/*
*
*    OPEN-XCHANGE legal information
*
*    All intellectual property rights in the Software are protected by
*    international copyright laws.
*
*
*    In some countries OX, OX Open-Xchange, open xchange and OXtender
*    as well as the corresponding Logos OX Open-Xchange and OX are registered
*    trademarks.
*    The use of the Logos is not covered by the GNU General Public License.
*    Instead, you are allowed to use these Logos according to the terms and
*    conditions of the Creative Commons License, Version 2.5, Attribution,
*    Non-commercial, ShareAlike, and the interpretation of the term
*    Non-commercial applicable to the aforementioned license is published
*    on the web site http://www.open-xchange.com/EN/legal/index.html.
*
*    Please make sure that third-party modules and libraries are used
*    according to their respective licenses.
*
*    Any modifications to this package must retain all copyright notices
*    of the original copyright holder(s) for the original code used.
*
*    After any such modifications, the original and derivative code shall remain
*    under the copyright of the copyright holder(s) and/or original author(s)per
*    the Attribution and Assignment Agreement that can be located at
*    http://www.open-xchange.com/EN/developer/. The contributing author shall be
*    given Attribution for the derivative code and a license granting use.
*
*     Copyright (C) 2016-2020 OX Software GmbH
*     Mail: info@open-xchange.com
*
*
*     This program is free software; you can redistribute it and/or modify it
*     under the terms of the GNU General Public License, Version 2 as published
*     by the Free Software Foundation.
*
*     This program is distributed in the hope that it will be useful, but
*     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
*     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
*     for more details.
*
*     You should have received a copy of the GNU General Public License along
*     with this program; if not, write to the Free Software Foundation, Inc., 59
*     Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
*/

package com.openexchange.office.rt2.core.doc;

import java.util.Date;
import java.util.List;
import org.apache.commons.lang3.Validate;
import org.json.JSONObject;

import com.openexchange.office.tools.doc.ApplicationType;
import com.openexchange.office.tools.doc.RecentFileListManager;


public class RecentFileListHelper
{

   /**
    * Provides the recent file list for the provided application type and
    * checks/does a is migration if needed.
    *
    * @param recentFileListManager
    *  The recent file list manager instance to be used to retrieve the
    *  recent file list.
    *
    * @param app
    *  Selects for what application the recent file list should be retrieved.
    *
    * @return
    */
   public static List<JSONObject> getRecentFileList(RecentFileListManager recentFileListManager, ApplicationType app) {
       List<JSONObject> recentFileList = recentFileListManager.readRecentFileList(app);
       if (null == recentFileList) {
           // migrate old list for app on demand
           recentFileListManager.migrateOldRecentFileList(app);
           recentFileList = recentFileListManager.readRecentFileList(app);
       }
       return recentFileList;
   }

   /**
    * Adds a file to the recent file - the order will be changed, if the file
    * is already part of the recent file list.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @return
    *  TRUE if the file has been added/set to the top, otherwise FALSE.
    */
   public static boolean addToRecentFileList(final RecentFileListManager recentFileListManager, ApplicationType app, final JSONObject addToFile, final Date lastSaveTime) {
       if (null != recentFileListManager) {
           List<JSONObject> recentFileList = RecentFileListHelper.getRecentFileList(recentFileListManager, app);
           if (null != recentFileList) {
               recentFileListManager.addCurrentFile(recentFileList, addToFile, lastSaveTime);
               recentFileListManager.writeRecentFileList(app, recentFileList);
               recentFileListManager.flush();
               return true;
           }
       }
       return false;
   }

   /**
    * Updates the file of the recent file list. If the file is not part of the
    * recent file list, nothing will happen.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @param oldFile
    * @param newFile
    * @param lastSaveTime
    *
    * @return
    *  TRUE if the file has been updated, otherwise FALSE.
    */
   public static boolean updateFileInRecentFileList(final RecentFileListManager recentFileListManager, ApplicationType app, final String oldFileId, final JSONObject newFile, final Date lastSaveTime) {
       Validate.notNull(newFile, "The new file descriptor must always be provided and cannot be null!");

       if (null != recentFileListManager) {
           List<JSONObject> recentFileList = RecentFileListHelper.getRecentFileList(recentFileListManager, app);
           if (null != recentFileList) {
               recentFileListManager.updateFile(recentFileList, oldFileId, newFile, lastSaveTime);
               recentFileListManager.writeRecentFileList(app, recentFileList);
               recentFileListManager.flush();
               return true;
           }
       }
       return false;
   }

   /**
    * Removes a file from the recent file list and store it.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @param folderId
    *  The folder id of the file to be removed.
    *
    * @param fileId
    *  The file id of the file to be removed.
    *
    * @return
    *  TRUE if the file has been removed, otherwise FALSE.
    */
   public static boolean removeFromRecentFileList(RecentFileListManager recentFileListManager, ApplicationType app, String folderId, String fileId) {
       boolean result = false;

       List<JSONObject> recentFileList = getRecentFileList(recentFileListManager, app);
       if (null != recentFileList) {
           JSONObject removeFileDescriptor = RecentFileListManager.createFileDescriptor(folderId, fileId);
           if (null != removeFileDescriptor) {
               boolean changed = recentFileListManager.removeFileFromList(recentFileList, removeFileDescriptor);
               if (changed) {
                   recentFileListManager.writeRecentFileList(app, recentFileList);
                   recentFileListManager.flush();
                   result = true;
               }
           }
       }

       return result;
   }
}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/RecentFileListHelper.java <==
/*
*
*    OPEN-XCHANGE legal information
*
*    All intellectual property rights in the Software are protected by
*    international copyright laws.
*
*
*    In some countries OX, OX Open-Xchange, open xchange and OXtender
*    as well as the corresponding Logos OX Open-Xchange and OX are registered
*    trademarks.
*    The use of the Logos is not covered by the GNU General Public License.
*    Instead, you are allowed to use these Logos according to the terms and
*    conditions of the Creative Commons License, Version 2.5, Attribution,
*    Non-commercial, ShareAlike, and the interpretation of the term
*    Non-commercial applicable to the aforementioned license is published
*    on the web site http://www.open-xchange.com/EN/legal/index.html.
*
*    Please make sure that third-party modules and libraries are used
*    according to their respective licenses.
*
*    Any modifications to this package must retain all copyright notices
*    of the original copyright holder(s) for the original code used.
*
*    After any such modifications, the original and derivative code shall remain
*    under the copyright of the copyright holder(s) and/or original author(s)per
*    the Attribution and Assignment Agreement that can be located at
*    http://www.open-xchange.com/EN/developer/. The contributing author shall be
*    given Attribution for the derivative code and a license granting use.
*
*     Copyright (C) 2016 OX Software GmbH
*     Mail: info@open-xchange.com
*
*
*     This program is free software; you can redistribute it and/or modify it
*     under the terms of the GNU General Public License, Version 2 as published
*     by the Free Software Foundation.
*
*     This program is distributed in the hope that it will be useful, but
*     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
*     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
*     for more details.
*
*     You should have received a copy of the GNU General Public License along
*     with this program; if not, write to the Free Software Foundation, Inc., 59
*     Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
*/

package com.openexchange.office.rt2.core.doc;

import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.Validate;
import org.json.JSONObject;

import com.openexchange.office.recentfilelist.RecentFileListManager;
import com.openexchange.office.tools.doc.ApplicationType;


public class RecentFileListHelper
{

   /**
    * Provides the recent file list for the provided application type and
    * checks/does a is migration if needed.
    *
    * @param recentFileListManager
    *  The recent file list manager instance to be used to retrieve the
    *  recent file list.
    *
    * @param app
    *  Selects for what application the recent file list should be retrieved.
    *
    * @return
    */
   public static List<JSONObject> getRecentFileList(RecentFileListManager recentFileListManager, ApplicationType app) {
       List<JSONObject> recentFileList = recentFileListManager.readRecentFileList(app);
       if (null == recentFileList) {
           // migrate old list for app on demand
           recentFileListManager.migrateOldRecentFileList(app);
           recentFileList = recentFileListManager.readRecentFileList(app);
       }
       return recentFileList;
   }

   /**
    * Adds a file to the recent file - the order will be changed, if the file
    * is already part of the recent file list.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @return
    *  TRUE if the file has been added/set to the top, otherwise FALSE.
    */
   public static boolean addToRecentFileList(final RecentFileListManager recentFileListManager, ApplicationType app, final JSONObject addToFile, final Date lastSaveTime) {
       if (null != recentFileListManager) {
           List<JSONObject> recentFileList = RecentFileListHelper.getRecentFileList(recentFileListManager, app);
           if (null != recentFileList) {
               recentFileListManager.addCurrentFile(recentFileList, addToFile, lastSaveTime);
               recentFileListManager.writeRecentFileList(app, recentFileList);
               recentFileListManager.flush();
               return true;
           }
       }
       return false;
   }

   /**
    * Updates the file of the recent file list. If the file is not part of the
    * recent file list, nothing will happen.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @param oldFile
    * @param newFile
    * @param lastSaveTime
    *
    * @return
    *  TRUE if the file has been updated, otherwise FALSE.
    */
   public static boolean updateFileInRecentFileList(final RecentFileListManager recentFileListManager, ApplicationType app, final String oldFileId, final JSONObject newFile, final Date lastSaveTime) {
       Validate.notNull(newFile, "The new file descriptor must always be provided and cannot be null!");

       if (null != recentFileListManager) {
           List<JSONObject> recentFileList = RecentFileListHelper.getRecentFileList(recentFileListManager, app);
           if (null != recentFileList) {
               recentFileListManager.updateFile(recentFileList, oldFileId, newFile, lastSaveTime);
               recentFileListManager.writeRecentFileList(app, recentFileList);
               recentFileListManager.flush();
               return true;
           }
       }
       return false;
   }

   /**
    * Removes a file from the recent file list and store it.
    *
    * @param recentFileListManager
    *  A recent file list manager instance.
    *
    * @param app
    *  The application type that specifies which recent file list should
    *  be updated.
    *
    * @param folderId
    *  The folder id of the file to be removed.
    *
    * @param fileId
    *  The file id of the file to be removed.
    *
    * @return
    *  TRUE if the file has been removed, otherwise FALSE.
    */
   public static boolean removeFromRecentFileList(RecentFileListManager recentFileListManager, ApplicationType app, String folderId, String fileId) {
       boolean result = false;

       List<JSONObject> recentFileList = getRecentFileList(recentFileListManager, app);
       if (null != recentFileList) {
           JSONObject removeFileDescriptor = recentFileListManager.createFileDescriptor(folderId, fileId);
           if (null != removeFileDescriptor) {
               boolean changed = recentFileListManager.removeFileFromList(recentFileList, removeFileDescriptor);
               if (changed) {
                   recentFileListManager.writeRecentFileList(app, recentFileList);
                   recentFileListManager.flush();
                   result = true;
               }
           }
       }

       return result;
   }
}
